# carbon3d-client
An API to interact with Carbon's Manufacturing Cloud including 3D model upload, automated order processing and part history.

Getting started
---------------

- [Generate and download an API key](https://carbon3d.print.carbon3d.com/api_keys)
  - Your API key and client secret will be downloaded into a secret.json file.

- [Use generated API key to generate a JWT token](/token_generator) from the api key.
  - If your API key is revoked, this token will no longer work.

- Authorize with generated token

- Upload mesh files

- Create orders

- Monitor order status


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.1
- Package version: 0.0.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.carbon3d.com](https://www.carbon3d.com)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import carbon3d
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import carbon3d
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import carbon3d
from carbon3d.rest import ApiException
from pprint import pprint

configuration = carbon3d.Configuration()
# Configure Bearer authorization (JWT): bearerAuth
configuration.access_token = 'YOUR_BEARER_TOKEN'

# Defining host is optional and default to https://api-sandbox.carbon3d.com/v1
configuration.host = "https://api-sandbox.carbon3d.com/v1"
# Enter a context with an instance of the API client
with carbon3d.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = carbon3d.BuildsApi(api_client)
    uuid = 'uuid_example' # str | Build Uuid

    try:
        # Fetch a build
        api_response = api_instance.get_build(uuid)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BuildsApi->get_build: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://api-sandbox.carbon3d.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BuildsApi* | [**get_build**](docs/BuildsApi.md#get_build) | **GET** /builds/{uuid} | Fetch a build
*BuildsApi* | [**get_builds**](docs/BuildsApi.md#get_builds) | **GET** /builds | Fetch builds
*ModelsApi* | [**get_model**](docs/ModelsApi.md#get_model) | **GET** /models/{uuid} | Get a model by UUID
*ModelsApi* | [**get_models**](docs/ModelsApi.md#get_models) | **GET** /models | Fetch models
*ModelsApi* | [**upload_model**](docs/ModelsApi.md#upload_model) | **POST** /models | Upload a model
*OrdersApi* | [**create_order**](docs/OrdersApi.md#create_order) | **POST** /orders | Create an Order
*OrdersApi* | [**delete_order**](docs/OrdersApi.md#delete_order) | **DELETE** /orders/{uuid} | Cancel an Order
*OrdersApi* | [**get_order**](docs/OrdersApi.md#get_order) | **GET** /orders/{uuid} | Get an Order
*OrdersApi* | [**get_orders**](docs/OrdersApi.md#get_orders) | **GET** /orders | Fetch orders
*PartsApi* | [**create_part**](docs/PartsApi.md#create_part) | **POST** /parts | Create a Part
*PartsApi* | [**get_part**](docs/PartsApi.md#get_part) | **GET** /parts/{uuid} | Fetch a Part
*PartsApi* | [**get_parts**](docs/PartsApi.md#get_parts) | **GET** /parts | Fetch parts
*PrintedPartsApi* | [**get_printed_part**](docs/PrintedPartsApi.md#get_printed_part) | **GET** /printed_parts/{uuid} | Fetch a printed Part
*PrintedPartsApi* | [**get_printed_parts**](docs/PrintedPartsApi.md#get_printed_parts) | **GET** /printed_parts | Fetch printed parts
*PrintersApi* | [**get_printer**](docs/PrintersApi.md#get_printer) | **GET** /printers/{name} | Fetch a specific printer&#39;s status information
*PrintersApi* | [**get_printers**](docs/PrintersApi.md#get_printers) | **GET** /printers | Fetch all printer&#39;s status information
*PrintsApi* | [**get_prints**](docs/PrintsApi.md#get_prints) | **GET** /prints | List print information


## Documentation For Models

 - [Build](docs/Build.md)
 - [BuildsResponse](docs/BuildsResponse.md)
 - [Model](docs/Model.md)
 - [ModelPrint](docs/ModelPrint.md)
 - [ModelsResponse](docs/ModelsResponse.md)
 - [Order](docs/Order.md)
 - [OrderRequest](docs/OrderRequest.md)
 - [OrderRequestParts](docs/OrderRequestParts.md)
 - [OrderStatus](docs/OrderStatus.md)
 - [OrdersResponse](docs/OrdersResponse.md)
 - [Part](docs/Part.md)
 - [PartGenealogy](docs/PartGenealogy.md)
 - [PartGenealogyBuildInfo](docs/PartGenealogyBuildInfo.md)
 - [PartGenealogyPrintInfo](docs/PartGenealogyPrintInfo.md)
 - [PartRequest](docs/PartRequest.md)
 - [PartsResponse](docs/PartsResponse.md)
 - [PrintedPart](docs/PrintedPart.md)
 - [PrintedPartRef](docs/PrintedPartRef.md)
 - [PrintedPartStatus](docs/PrintedPartStatus.md)
 - [PrintedPartsResponse](docs/PrintedPartsResponse.md)
 - [Printer](docs/Printer.md)
 - [PrinterPrints](docs/PrinterPrints.md)
 - [PrinterStatus](docs/PrinterStatus.md)
 - [PrintersResponse](docs/PrintersResponse.md)
 - [PrintsResponse](docs/PrintsResponse.md)


## Documentation For Authorization


## bearerAuth

- **Type**: Bearer authentication (JWT)


## Author

api-list@carbon3d.com


